chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
  if (request.action === "getInfo") {
    // 现有的正则表达式
    const amountRegex = /(?<!另需运费\(预估\)：)[^\d]*(\d+(?:\.\d+)?)[^\d]*元|(?<!另需运费\(预估\)：)[^\d]*(\d+(?:\.\d+)?)[^\d]*元/g;
    const shippingRegex = /另需运费\(预估\)：[^\d]*(\d+(?:\.\d+)?)[^\d]*元/;

    // 新增的正则表达式
    const newAmountRegex = /商品金额：(\d+(?:\.\d{1,2})?)元/g;
    const additionalAmountRegex = /(\d+(?:\.\d{1,2})?)元\s*已选清单/g;

    const bodyText = document.body.innerText;

    // 匹配新增的金额
    const newAmountMatches = [...bodyText.matchAll(newAmountRegex)];
    if (newAmountMatches.length > 0) {
      // 如果找到商品金额，则直接使用第一个匹配的金额
      const amount = parseFloat(newAmountMatches[0][1]).toFixed(2);
      const shippingMatch = bodyText.match(shippingRegex);
      const shipping = shippingMatch ? shippingMatch[1] : '未找到';

      sendResponse({amount: amount, shipping: shipping});
      return;
    }

    // 匹配额外的金额类型
    const additionalAmountMatches = [...bodyText.matchAll(additionalAmountRegex)];

    // 如果找到额外类型的金额，则直接使用第一个匹配的金额
    if (additionalAmountMatches.length > 0) {
      const amount = parseFloat(additionalAmountMatches[0][1]).toFixed(2);
      const shippingMatch = bodyText.match(shippingRegex);
      const shipping = shippingMatch ? shippingMatch[1] : '未找到';

      sendResponse({amount: amount, shipping: shipping});
      return;
    }

    // 匹配现有的金额
    const amountMatches = [...bodyText.matchAll(amountRegex)];
    const shippingMatch = bodyText.match(shippingRegex);

    let maxAmount = -Infinity;

    // 处理现有的金额匹配结果
    for (const match of amountMatches) {
      const amount = match[1] ? parseFloat(match[1]) : parseFloat(match[2]);
      if (!isNaN(amount) && amount > maxAmount) {
        maxAmount = amount;
      }
    }

    const amount = maxAmount !== -Infinity ? maxAmount.toFixed(2) : '未找到';
    const shipping = shippingMatch ? shippingMatch[1] : '未找到';

    sendResponse({amount: amount, shipping: shipping});
  }
});
